@@ -1,3 +1,5 @@
+from typing import Optional
+
 import typer
 
 from partifact.auth_token import get_token
@@ -6,14 +8,26 @@ from partifact.shell_commands import configure_pip, configure_poetry
 
 app = typer.Typer()
 
+profile_option = typer.Option(
+    None, help="The AWS profile to use when getting the CodeArtifact token."
+)
+
+role_option = typer.Option(
+    None, help="The AWS role to use when getting the CodeArtifact token."
+)
+
 
 @app.command()
-def login(repository: str):
+def login(
+    repository: str,
+    profile: Optional[str] = profile_option,
+    role: Optional[str] = role_option,
+) -> None:
     """Log into CodeArtifact.
 
     This configures pip and poetry to make use of the created CodeArtifact session.
     """
-    config = Configuration.load(repository)
+    config = Configuration.load(repository, profile, role)
     token = get_token(config)
 
     configure_pip(config, token)
